@@ -173,6 +173,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -193,7 +195,7 @@ class CloudFrontToApiGateway(
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -208,6 +210,10 @@ class CloudFrontToApiGateway(
         :since: 0.8.0
         :summary: Constructs a new instance of the CloudFrontToApiGateway class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudFrontToApiGateway.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToApiGatewayProps(
             existing_api_gateway_obj=existing_api_gateway_obj,
             cloud_front_distribution_props=cloud_front_distribution_props,
@@ -254,7 +260,7 @@ class CloudFrontToApiGatewayProps:
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -267,6 +273,12 @@ class CloudFrontToApiGatewayProps:
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
             cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudFrontToApiGatewayProps.__init__)
+            check_type(argname="argument existing_api_gateway_obj", value=existing_api_gateway_obj, expected_type=type_hints["existing_api_gateway_obj"])
+            check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
+            check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
+            check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
